==> sqslambda-1.168.0-sources.jar: software/amazon/awsconstructs/services/sqslambda/SqsToLambda.java <==
package software.amazon.awsconstructs.services.sqslambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.65.0 (build 7a02b7f)", date = "2022-08-22T21:35:51.523Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.sqslambda.$Module.class, fqn = "@aws-solutions-constructs/aws-sqs-lambda.SqsToLambda")
public class SqsToLambda extends software.amazon.awscdk.core.Construct {

    protected SqsToLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SqsToLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public SqsToLambda(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.sqslambda.SqsToLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sqs.Queue getSqsQueue() {
        return software.amazon.jsii.Kernel.get(this, "sqsQueue", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.sqs.Queue.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.sqs.DeadLetterQueue getDeadLetterQueue() {
        return software.amazon.jsii.Kernel.get(this, "deadLetterQueue", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.sqs.DeadLetterQueue.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.sqslambda.SqsToLambda}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.sqslambda.SqsToLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.sqslambda.SqsToLambdaProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.sqslambda.SqsToLambdaProps.Builder();
        }

        /**
         * Optional user provided properties for the dead letter queue.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param deadLetterQueueProps Optional user provided properties for the dead letter queue. This parameter is required.
         */
        public Builder deadLetterQueueProps(final software.amazon.awscdk.services.sqs.QueueProps deadLetterQueueProps) {
            this.props.deadLetterQueueProps(deadLetterQueueProps);
            return this;
        }

        /**
         * Whether to deploy a secondary queue to be used as a dead letter queue.
         * <p>
         * Default: - true.
         * <p>
         * @return {@code this}
         * @param deployDeadLetterQueue Whether to deploy a secondary queue to be used as a dead letter queue. This parameter is required.
         */
        public Builder deployDeadLetterQueue(final java.lang.Boolean deployDeadLetterQueue) {
            this.props.deployDeadLetterQueue(deployDeadLetterQueue);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * Existing instance of SQS queue object, Providing both this and queueProps will cause an error.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param existingQueueObj Existing instance of SQS queue object, Providing both this and queueProps will cause an error. This parameter is required.
         */
        public Builder existingQueueObj(final software.amazon.awscdk.services.sqs.Queue existingQueueObj) {
            this.props.existingQueueObj(existingQueueObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue.
         * <p>
         * Default: - required field if deployDeadLetterQueue=true.
         * <p>
         * @return {@code this}
         * @param maxReceiveCount The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. This parameter is required.
         */
        public Builder maxReceiveCount(final java.lang.Number maxReceiveCount) {
            this.props.maxReceiveCount(maxReceiveCount);
            return this;
        }

        /**
         * Optional user provided properties.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param queueProps Optional user provided properties. This parameter is required.
         */
        public Builder queueProps(final software.amazon.awscdk.services.sqs.QueueProps queueProps) {
            this.props.queueProps(queueProps);
            return this;
        }

        /**
         * Optional user provided properties for the queue event source.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param sqsEventSourceProps Optional user provided properties for the queue event source. This parameter is required.
         */
        public Builder sqsEventSourceProps(final software.amazon.awscdk.services.lambda.eventsources.SqsEventSourceProps sqsEventSourceProps) {
            this.props.sqsEventSourceProps(sqsEventSourceProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.sqslambda.SqsToLambda}.
         */
        @Override
        public software.amazon.awsconstructs.services.sqslambda.SqsToLambda build() {
            return new software.amazon.awsconstructs.services.sqslambda.SqsToLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> sqslambda-2.57.0-sources.jar: software/amazon/awsconstructs/services/sqslambda/SqsToLambda.java <==
package software.amazon.awsconstructs.services.sqslambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.98.0 (build 00b106d)", date = "2024-05-06T21:40:37.593Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.sqslambda.$Module.class, fqn = "@aws-solutions-constructs/aws-sqs-lambda.SqsToLambda")
public class SqsToLambda extends software.constructs.Construct {

    protected SqsToLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected SqsToLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
     * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
     * @param props <ul><li>user provided props for the construct.</li></ul> This parameter is required.
     */
    public SqsToLambda(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.sqslambda.SqsToLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.sqs.Queue getSqsQueue() {
        return software.amazon.jsii.Kernel.get(this, "sqsQueue", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.sqs.Queue.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.sqs.DeadLetterQueue getDeadLetterQueue() {
        return software.amazon.jsii.Kernel.get(this, "deadLetterQueue", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.sqs.DeadLetterQueue.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.sqslambda.SqsToLambda}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.sqslambda.SqsToLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
         * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.sqslambda.SqsToLambdaProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.sqslambda.SqsToLambdaProps.Builder();
        }

        /**
         * Optional user provided properties for the dead letter queue.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param deadLetterQueueProps Optional user provided properties for the dead letter queue. This parameter is required.
         */
        public Builder deadLetterQueueProps(final software.amazon.awscdk.services.sqs.QueueProps deadLetterQueueProps) {
            this.props.deadLetterQueueProps(deadLetterQueueProps);
            return this;
        }

        /**
         * Whether to deploy a secondary queue to be used as a dead letter queue.
         * <p>
         * Default: - true.
         * <p>
         * @return {@code this}
         * @param deployDeadLetterQueue Whether to deploy a secondary queue to be used as a dead letter queue. This parameter is required.
         */
        public Builder deployDeadLetterQueue(final java.lang.Boolean deployDeadLetterQueue) {
            this.props.deployDeadLetterQueue(deployDeadLetterQueue);
            return this;
        }

        /**
         * If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key.
         * <p>
         * This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps.
         * <p>
         * Default: - False if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
         * <p>
         * @return {@code this}
         * @param enableEncryptionWithCustomerManagedKey If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This parameter is required.
         */
        public Builder enableEncryptionWithCustomerManagedKey(final java.lang.Boolean enableEncryptionWithCustomerManagedKey) {
            this.props.enableEncryptionWithCustomerManagedKey(enableEncryptionWithCustomerManagedKey);
            return this;
        }

        /**
         * An optional, imported encryption key to encrypt the SQS queue with.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param encryptionKey An optional, imported encryption key to encrypt the SQS queue with. This parameter is required.
         */
        public Builder encryptionKey(final software.amazon.awscdk.services.kms.Key encryptionKey) {
            this.props.encryptionKey(encryptionKey);
            return this;
        }

        /**
         * Optional user provided properties to override the default properties for the KMS encryption key used to  encrypt the SQS queue with.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param encryptionKeyProps Optional user provided properties to override the default properties for the KMS encryption key used to  encrypt the SQS queue with. This parameter is required.
         */
        public Builder encryptionKeyProps(final software.amazon.awscdk.services.kms.KeyProps encryptionKeyProps) {
            this.props.encryptionKeyProps(encryptionKeyProps);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * Existing instance of SQS queue object, Providing both this and queueProps will cause an error.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param existingQueueObj Existing instance of SQS queue object, Providing both this and queueProps will cause an error. This parameter is required.
         */
        public Builder existingQueueObj(final software.amazon.awscdk.services.sqs.Queue existingQueueObj) {
            this.props.existingQueueObj(existingQueueObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue.
         * <p>
         * Default: - required field if deployDeadLetterQueue=true.
         * <p>
         * @return {@code this}
         * @param maxReceiveCount The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. This parameter is required.
         */
        public Builder maxReceiveCount(final java.lang.Number maxReceiveCount) {
            this.props.maxReceiveCount(maxReceiveCount);
            return this;
        }

        /**
         * Optional user provided properties.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param queueProps Optional user provided properties. This parameter is required.
         */
        public Builder queueProps(final software.amazon.awscdk.services.sqs.QueueProps queueProps) {
            this.props.queueProps(queueProps);
            return this;
        }

        /**
         * Optional user provided properties for the queue event source.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param sqsEventSourceProps Optional user provided properties for the queue event source. This parameter is required.
         */
        public Builder sqsEventSourceProps(final software.amazon.awscdk.services.lambda.eventsources.SqsEventSourceProps sqsEventSourceProps) {
            this.props.sqsEventSourceProps(sqsEventSourceProps);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awsconstructs.services.sqslambda.SqsToLambda}.
         */
        @Override
        public software.amazon.awsconstructs.services.sqslambda.SqsToLambda build() {
            return new software.amazon.awsconstructs.services.sqslambda.SqsToLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
